`PyRemoteData` Documentation
============================

`PyRemoteData` is a Python package for downloading and managing remote data on servers supporting the SFTP protocol. 
It has been developed to facilitate high-throughput data transfer in high-bandwidth/high-latency situations (over the internet) for machine learning applications, but can be used for any application requiring remote data access.

.. toctree::
   :maxdepth: 1

   installation
   quickstart
   usage
   erda
   api/implicit_mount
   api/config

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`

